adjust plugin to be part of ext/, adjust plugin name
diff --git a/setup.py b/setup.py
index 0dc1afd..1f0ef3a 100644
--- a/setup.py
+++ b/setup.py
@@ -39,6 +39,6 @@
       ],
       entry_points="""
       [python.templating.engines]
-      mako = mako.plugin:TGPlugin
+      mako-tg = mako.ext.turbogears:TGPlugin
       """,
 )
diff --git a/lib/mako/plugin.py b/lib/mako/ext/turbogears.py
similarity index 100%
rename from lib/mako/plugin.py
rename to lib/mako/ext/turbogears.py
diff --git a/lib/mako/runtime.py b/lib/mako/runtime.py
index 9ada09a..4f1792c 100644
--- a/lib/mako/runtime.py
+++ b/lib/mako/runtime.py
@@ -102,7 +102,9 @@
     uri = property(lambda s:s.template.uri)
     
     def get_namespace(self, uri):
-        """return a namespace corresponding to the given template filename."""
+        """return a namespace corresponding to the given template uri.
+        
+        if a relative uri, it is adjusted to that of the template of this namespace"""
         key = (self, uri)
         if self.context.namespaces.has_key(key):
             return context.namespaces[key]